library(scales)
library("gridExtra")
library(grid)
library(ggpubr)
library(Seurat)

rds.path <- commandArgs(trailingOnly = TRUE)[1]
section <- commandArgs(trailingOnly = TRUE)[2]
deconv_path <-  commandArgs(trailingOnly = TRUE)[3]
reference_atlas <-  commandArgs(trailingOnly = TRUE)[4]
ncell <-  commandArgs(trailingOnly = TRUE)[5]
alpha <-  commandArgs(trailingOnly = TRUE)[6]
utils_path <- commandArgs(trailingOnly = TRUE)[7]

print(deconv_path)

source(utils_path)

  seurat <- readRDS(rds.path)
  # read deconvolution
  
  result <- convert.output.cell2loc(deconv_path)
  result <- na.omit(result[paste(section, '_', colnames(seurat), sep=''),])
  rownames(result) <- gsub(paste(section,'_',sep=''), '',rownames(result))
  deconvolution <- CreateAssayObject(t(as.matrix(result)))
  seurat[['deconvolution']] <- deconvolution
  DefaultAssay(seurat) <- "deconvolution"
  
  extrapolation <- CreateAssayObject(floor(t(as.matrix(result))))
  seurat[['extrapolationfloor']] <- extrapolation
  DefaultAssay(seurat) <- "extrapolationfloor"
  extrapolation.df <- extrapolate.deconvolution.from.matrix(seurat@assays$extrapolationfloor@counts)
  extrapolation.df.floor <- extrapolation.df
  attributes(seurat@assays$extrapolationfloor)$extrapolation.df <- extrapolation.df
  pdf(file = './floor.pdf')
  print(SpatialExtrapolationPlot(seurat, point.size.factor = 1, jitter = 50) + facet_wrap(~ident) + NoLegend() )
  dev.off()

  
  extrapolation <- CreateAssayObject(round(t(as.matrix(result))))
  seurat[['extrapolationround']] <- extrapolation
  DefaultAssay(seurat) <- "extrapolationround"
  extrapolation.df <- extrapolate.deconvolution.from.matrix(seurat@assays$extrapolationround@counts)
  extrapolation.df.round <- extrapolation.df
  attributes(seurat@assays$extrapolationround)$extrapolation.df <- extrapolation.df
  pdf('./round.pdf')
  print(SpatialExtrapolationPlot(seurat, point.size.factor = 1, jitter = 50) + facet_wrap(~ident) + NoLegend() )
  dev.off()

  
  saveRDS(seurat, paste('./',section, "_",reference_atlas,'_', ncell, '_',alpha ,".rds", sep=""))
  
  #plot cell type density
  DefaultAssay(seurat) <- "deconvolution"
  
  for(celltype in rownames(seurat)){
    save_folder <- './celltype/'
    if (!dir.exists(save_folder)) {dir.create(save_folder)}
    png(paste(save_folder,celltype,'.png', sep=""), width=1000)
    DefaultAssay(seurat) <- 'deconvolution'
    p1<-SpatialFeaturePlot(seurat, celltype)+ scale_fill_viridis_c(option = "magma");p2<-ggplot() + aes(x=seurat@assays$deconvolution@counts[celltype,]) + geom_histogram(bins = 100,)+geom_vline(xintercept = 0.5, color='red')+geom_vline(xintercept = 1, color='orange');print(p1+p2)
    dev.off()
    DefaultAssay(seurat) <- 'extrapolationround'
    png(paste(save_folder,celltype,'_extrapolation.png', sep=""), width=550) 
    p1<-SpatialExtrapolationPlot(seurat, point.size.factor = 0.6, jitter = 55, idents = celltype, crop=F)
    print(p1)
    dev.off()
  }
  