library(Seurat)
library(ggplot2)
library(pheatmap)
library(RColorBrewer)

### Load Seurat object
seurat <- readRDS("../5618_CAF-S1_OV.rds")
seurat@meta.data$treatment <- factor(seurat@meta.data$treatment, levels = c("treatment_naive","treated"))
seurat@meta.data$CAF.annotation <- factor(seurat@meta.data$CAF.annotation,
                                            levels = c("ECM-myCAF","Detox-iCAF","IL-myCAF","TGFb-myCAF",
                                                       "Wound-myCAF","IFNg-iCAF","IFNa/b-myCAF","Acto-myCAF"))


#############################################################################
### Load output from cNMF
#############################################################################
cell.k <- read.delim("Output_cNMF/res_cNMF_1/res_cNMF_1.usages.k_10.dt_0_1.consensus.txt")
head(cell.k)
rownames(cell.k) <- cell.k$cell.ID

meta <- seurat@meta.data
meta$cell.ID <- rownames(meta)
head(meta)
cell.k <- merge(cell.k,meta, by.x = "cell.ID", by.y ="cell.ID", all.x=TRUE)
rownames(cell.k) <- cell.k$cell.ID

pheno <- cell.k[,c("treatment","CAF.annotation")]
rownames(pheno) <- cell.k$cell.ID

ann_colors = list(
  treatment = c(treatment_naive="black", treated="gray"),
  Final.annotation = c("ECM-myCAF"="#D88A7D", "Detox-iCAF"="#B4A366","IL-myCAF"="#808F57","TGFb-myCAF"="#7EB695","Wound-myCAF"="#8BB7B8","IFNg-iCAF"="#7AB3D5","IFNa/b-myCAF"="#A68CB0","Acto-myCAF"="#F361CC")
  )

if(identical(rownames(pheno),cell.k$cell.ID)){
  p <- pheatmap(t(cell.k[,2:11]),
                cluster_rows = T,
                cluster_cols = T,
                clustering_distance_rows="correlation", ## correlation, euclidean
                clustering_distance_cols="correlation",
                clustering_method="ward.D2",
                show_rownames=T,
                show_colnames = F,
                scale = "row",
                annotation_col = pheno,
                annotation_colors = ann_colors,
                #annotation_row = class.cell,
                colorRampPalette(rev(brewer.pal(n=11, name="RdBu")))(100),
                border_color=NA,
                breaks=seq(-3, 3, length.out=101)
  )
  ggsave("heatmap_cNMF_k10_dt_0_1.pdf",p,device = "pdf", width = 30, height = 10)
}
